state

package
v0.4.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 15, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Save

func Save(s AppState) error

Save writes the app state to disk, creating the directory if needed.

Types

type AppState

type AppState struct {
	LastSeenVersion string `json:"last_seen_version"`
}

AppState holds persistent application state (separate from user config).

func Load

func Load() AppState

Load reads the app state from disk. Returns zero value if file is missing or unreadable.

Jump to