Documentation
¶
Index ¶
- type AnalysisResult
- type AttributeAnalysisResult
- type OTLPAnalyzer
- func (oa *OTLPAnalyzer) AnalyzeOTLPLogsData(logsData *logspb.LogsData) *AnalysisResult
- func (oa *OTLPAnalyzer) AnalyzeOTLPRecord(record *logspb.LogRecord) *AnalysisResult
- func (oa *OTLPAnalyzer) ExtractAttributesFromOTLPLogsData(logsData *logspb.LogsData) map[string]string
- func (oa *OTLPAnalyzer) ExtractAttributesFromOTLPRecord(record *logspb.LogRecord) map[string]string
- type TextAnalyzer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AnalysisResult ¶
type AttributeAnalysisResult ¶
AttributeAnalysisResult contains extracted attributes
type OTLPAnalyzer ¶
type OTLPAnalyzer struct {
// contains filtered or unexported fields
}
OTLPAnalyzer analyzes OTLP log records and extracts text for frequency analysis
func NewOTLPAnalyzer ¶
func NewOTLPAnalyzer() *OTLPAnalyzer
NewOTLPAnalyzer creates a new OTLP analyzer
func (*OTLPAnalyzer) AnalyzeOTLPLogsData ¶
func (oa *OTLPAnalyzer) AnalyzeOTLPLogsData(logsData *logspb.LogsData) *AnalysisResult
AnalyzeOTLPLogsData analyzes an entire OTLP LogsData structure Only analyzes the actual log message bodies, not metadata
func (*OTLPAnalyzer) AnalyzeOTLPRecord ¶
func (oa *OTLPAnalyzer) AnalyzeOTLPRecord(record *logspb.LogRecord) *AnalysisResult
AnalyzeOTLPRecord analyzes an OTLP log record and extracts words and phrases
func (*OTLPAnalyzer) ExtractAttributesFromOTLPLogsData ¶
func (oa *OTLPAnalyzer) ExtractAttributesFromOTLPLogsData(logsData *logspb.LogsData) map[string]string
ExtractAttributesFromOTLPLogsData extracts all attribute key-value pairs from OTLP LogsData
func (*OTLPAnalyzer) ExtractAttributesFromOTLPRecord ¶
func (oa *OTLPAnalyzer) ExtractAttributesFromOTLPRecord(record *logspb.LogRecord) map[string]string
ExtractAttributesFromOTLPRecord extracts attribute key-value pairs from an OTLP log record
type TextAnalyzer ¶
type TextAnalyzer struct {
// contains filtered or unexported fields
}
func NewTextAnalyzer ¶
func NewTextAnalyzer() *TextAnalyzer
func (*TextAnalyzer) AnalyzeLine ¶
func (ta *TextAnalyzer) AnalyzeLine(line string) *AnalysisResult
Click to show internal directories.
Click to hide internal directories.