Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type FileReader ¶
type FileReader struct {
// contains filtered or unexported fields
}
FileReader manages reading from multiple files with optional follow mode
func New ¶
func New(filePaths []string, follow bool) (*FileReader, error)
New creates a new FileReader with the given file paths and options
func (*FileReader) GetFilePaths ¶
func (fr *FileReader) GetFilePaths() []string
GetFilePaths returns the list of files being read
func (*FileReader) Start ¶
func (fr *FileReader) Start() <-chan string
Start begins reading from the files
func (*FileReader) Stop ¶
func (fr *FileReader) Stop()
Stop stops the file reader and closes all resources
func (*FileReader) Wait ¶
func (fr *FileReader) Wait()
Wait waits for all reading goroutines to finish
Click to show internal directories.
Click to hide internal directories.