package
Version:
v0.4.3
Opens a new window with list of versions in this module.
Published: Jul 15, 2026
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Save writes the app state to disk, creating the directory if needed.
type AppState struct {
LastSeenVersion string `json:"last_seen_version"`
}
AppState holds persistent application state (separate from user config).
Load reads the app state from disk. Returns zero value if file is missing or unreadable.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.