Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
Client represents a Victoria Logs client for streaming logs
type Receiver ¶
type Receiver struct {
// contains filtered or unexported fields
}
Receiver implements a Victoria Logs receiver that streams logs to a channel
func NewReceiver ¶
NewReceiver creates a new Victoria Logs receiver
func (*Receiver) GetLineChan ¶
GetLineChan returns the channel for receiving log lines
Click to show internal directories.
Click to hide internal directories.